@@ -8,6 +8,7 @@ import inspect
 import json
 import os
 from pathlib import Path
+import re
 from string import Template
 import sys
 import time
@@ -20,6 +21,8 @@ from botocore.exceptions import ClientError
 from cloudfn.core.data import coalesce
 from cloudfn.core.util import TestHelper
 
+SSM_SUB_PATTERN = re.compile(r'\"\${sm:(.+?)}\"')
+
 class LambdaHandler:
 	"""Lambda handler decorator"""
 	_f = None
@@ -147,12 +150,36 @@ class LambdaHandler:
 				)
 
 				try:
-					LambdaHandler._config[alias] = json.load(s3_config_obj.get()['Body'])
-
+					# read config
+					config_text = s3_config_obj.get()['Body'].read().decode()
 					log.log('CNFG', 'Read config from S3', {
 						'bucket': s3_config_obj.bucket_name,
 						'key': s3_config_obj.key
 					})
+
+					# check for ssm vars
+					if secret_names := set(SSM_SUB_PATTERN.findall(config_text)):
+						log.log('CNFG', 'Attempting to inject secrets', {
+							'secrets': secret_names
+						})
+
+						# init SSM client
+						sec_client = boto3.client('secretsmanager')
+
+						# try to load secrets and inject
+						for secret_name in secret_names:
+							secret_response = sec_client.get_secret_value(SecretId=secret_name)
+							try:
+								# if secret is JSON, inject replacing the string val/quotes
+								json.loads(secret_response['SecretString'])
+								config_text = config_text.replace(f'"${{sm:{secret_name}}}"', secret_response['SecretString'])
+							except:
+								# not a JSON, inject as string (leave quotes)
+								config_text = config_text.replace(f'${{sm:{secret_name}}}', secret_response['SecretString'])
+
+					LambdaHandler._config[alias] = json.loads(config_text)
+
+					
 				except ClientError as ex:
 					log.log('CNFG', 'Unable to read config from S3', {
 						'bucket': s3_config_obj.bucket_name,
